Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMike Erwin <significant.bit@gmail.com>2017-04-08 07:50:36 +0300
committerMike Erwin <significant.bit@gmail.com>2017-04-08 08:19:48 +0300
commit0947c97fade7a5400e22d85b1f61c5a0f552976a (patch)
tree181186c3c31706c3e0c813b62990c9186e2fc6f6 /source/blender/editors/interface/interface_draw.c
parent1de61696fd2ffc9d800a2eff964045b90c9f2347 (diff)
OpenGL: use PRIM instead of GL enum everywhere else
Well, everywhere that uses Gawain for drawing. Places that call OpenGL directly still use GL enums. Part of T49043
Diffstat (limited to 'source/blender/editors/interface/interface_draw.c')
-rw-r--r--source/blender/editors/interface/interface_draw.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/editors/interface/interface_draw.c b/source/blender/editors/interface/interface_draw.c
index bf14ed9df94..0b1d58c5836 100644
--- a/source/blender/editors/interface/interface_draw.c
+++ b/source/blender/editors/interface/interface_draw.c
@@ -577,7 +577,7 @@ void ui_draw_but_IMAGE(ARegion *UNUSED(ar), uiBut *but, uiWidgetColors *UNUSED(w
/**
* Draw title and text safe areas.
*
* The first parameter is a GL_FLOAT, 2, KEEP_FLOAT vertex attrib
* The next 4 parameters are the offsets for the view, not the zones.
*/
void UI_draw_safe_areas(
@@ -773,7 +773,7 @@ static void waveform_draw_one(float *waveform, int nbr, const float col[3])
VertexBuffer_fill_attrib(vbo, pos_id, waveform);
/* TODO store the Batch inside the scope */
- Batch *batch = Batch_create(GL_POINTS, vbo, NULL);
+ Batch *batch = Batch_create(PRIM_POINTS, vbo, NULL);
Batch_set_builtin_program(batch, GPU_SHADER_2D_UNIFORM_COLOR);
Batch_Uniform4f(batch, "color", col[0], col[1], col[2], 1.0f);
Batch_draw(batch);
@@ -577,7 +577,7 @@ void ui_draw_but_IMAGE(ARegion *UNUSED(ar), uiBut *but, uiWidgetColors *UNUSED(w
* Draw title and text safe areas.
*
- * The first parameter is a GL_FLOAT, 2, KEEP_FLOAT vertex attrib
+ * The first parameter is a PRIM_FLOAT, 2, KEEP_FLOAT vertex attrib
* The next 4 parameters are the offsets for the view, not the zones.
*/